# Aniemore

**Aniemore (Artem Nikita Ilya EMOtion REcognition)** - это проект, созданный при поддержке Фонда Содействия Инновациям по конкурсу Код-ИИ (очередь I) тремя независимыми разработчками - Артем Аментес, Никита Давидчук и Илья Лубенец.

## О чем и что это?
Aniemore - это библиотека для Python, которая позволяет добавить в вашу программу возможнотсь определять эмоциональный фон речи человека как в голосе, так и в тексте. Для этого в библиотеке есть два соответсвующих модуля - Voice и Text. Инструкции по использованию будут добавляться по мере проработки самой библиотеки.

**Данный проект всё ещё находится на стадии разработки, но вы уже можете [опробовать его](#Install).**


## <a name="Install"></a>	Установка
```shell
pip install git+https://github.com/aniemore/Aniemore
```
<hr>

## Доп. ссылки

Все модели и датасеты, а так же примеры их использования вы можете посмотреть в нашем [HuggingFace профиле](https://huggingface.co/Aniemore)


## Citation
```
@misc{Aniemore,
  author = {Артем Аментес, Илья Лубенец, Никита Давидчук},
  title = {Открытая библиотека искусственного интеллекта для анализа и выявления эмоциональных оттенков речи человека},
  year = {2022},
  publisher = {GitHub},
  journal = {GitHub repository},
  howpublished = {\url{https://github.com/aniemore/Aniemore}},
  email = {hello@socialcode.ru}
}
```
